from setuptools import setup, find_packages

setup(
    name = 'calculate_lu',
    version = '1.0.1',
    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = []
)
